server/test/unittest_session.py
changeset 7398 26695dd703d8
parent 7364 aff846ce1050
child 7730 8d0edec31aaf
--- a/server/test/unittest_session.py	Thu May 19 10:36:26 2011 +0200
+++ b/server/test/unittest_session.py	Thu May 19 10:53:11 2011 +0200
@@ -74,9 +74,9 @@
             self.assertEqual(session.disabled_hook_categories, set())
             self.assertEqual(session.enabled_hook_categories, set(('metadata',)))
         # leaving context manager with no transaction running should reset the
         # transaction local storage (and associated pool)
         self.assertEqual(session._tx_data, {})
-        self.assertEqual(session.pool, None)
+        self.assertEqual(session.cnxset, None)
 
 if __name__ == '__main__':
     unittest_main()
@@ -74,9 +74,9 @@
             self.assertEqual(session.enabled_hook_categories, set(('metadata',)))
         # leaving context manager with no transaction running should reset the
-        # transaction local storage (and associated pool)
+        # transaction local storage (and associated cnxset)
         self.assertEqual(session._tx_data, {})